@@ -170,25 +170,25 @@ def plotsklearnresult(configini,videoSetting, frameSetting):
                         cv2.putText(frame, str(mulltiAnimalIDList[0]), (newX1, newY1), cv2.FONT_HERSHEY_COMPLEX, fontScale, (0,0,255), 4)
                         cv2.putText(frame, str(mulltiAnimalIDList[1]), (newX2, newY2), cv2.FONT_HERSHEY_COMPLEX, fontScale, (255,0,0), 4)
 
-                # # draw event timers
-                # for b in range(counters_no):
-                #     target_timers[b] = (1 / fps) * target_counters[b]
-                #     target_timers[b] = round(target_timers[b], 2)
-                #
-                # cv2.putText(frame, str('Timers'), (10, ((height - height) + spacingScale)), cv2.FONT_HERSHEY_COMPLEX, fontScale, (0, 255, 0), 4)
-                # addSpacer = 2
-                # for k in range(counters_no):
-                #     cv2.putText(frame, (str(target_names[k]) + ' ' + str(target_timers[k]) + str('s')), (10, (height - height) + spacingScale * addSpacer), cv2.FONT_HERSHEY_SIMPLEX, fontScale, (255, 0, 0), 4)
-                #     addSpacer += 1
-                # cv2.putText(frame, str('ensemble prediction'), (10, (height - height) + spacingScale * addSpacer), cv2.FONT_HERSHEY_SIMPLEX, fontScale, (0, 255, 0), 4)
-                #
-                # addSpacer += 1
-                # for p in range(counters_no):
-                #     TargetVal = int(currentDf.loc[currRow, [target_names[p]]])
-                #     if TargetVal == 1:
-                #         cv2.putText(frame, str(target_names[p]), (10, (height - height) + spacingScale * addSpacer), cv2.FONT_HERSHEY_TRIPLEX, int(fontScale*1.8), colors[p], 4)
-                #         target_counters[p] += 1
-                #         addSpacer += 1
+                # draw event timers
+                for b in range(counters_no):
+                    target_timers[b] = (1 / fps) * target_counters[b]
+                    target_timers[b] = round(target_timers[b], 2)
+
+                cv2.putText(frame, str('Timers'), (10, ((height - height) + spacingScale)), cv2.FONT_HERSHEY_COMPLEX, fontScale, (0, 255, 0), 4)
+                addSpacer = 2
+                for k in range(counters_no):
+                    cv2.putText(frame, (str(target_names[k]) + ' ' + str(target_timers[k]) + str('s')), (10, (height - height) + spacingScale * addSpacer), cv2.FONT_HERSHEY_SIMPLEX, fontScale, (255, 0, 0), 4)
+                    addSpacer += 1
+                cv2.putText(frame, str('ensemble prediction'), (10, (height - height) + spacingScale * addSpacer), cv2.FONT_HERSHEY_SIMPLEX, fontScale, (0, 255, 0), 4)
+
+                addSpacer += 1
+                for p in range(counters_no):
+                    TargetVal = int(currentDf.loc[currRow, [target_names[p]]])
+                    if TargetVal == 1:
+                        cv2.putText(frame, str(target_names[p]), (10, (height - height) + spacingScale * addSpacer), cv2.FONT_HERSHEY_TRIPLEX, int(fontScale*1.8), colors[p], 4)
+                        target_counters[p] += 1
+                        addSpacer += 1
                 if videoSetting == 1:
                     writer.write(frame)
                 if frameSetting == 1:
